/*
 * Calls a function in a DLL
 *
 * Copyright 2001 Malte Starostik <malte@kde.org>
 *
*/

#include "windows.h"

typedef void CALLBACK (*EntryPoint)(HWND, HINSTANCE, LPSTR, int);

int PASCAL WinMain (HINSTANCE inst, HINSTANCE prev, LPSTR cmdline, int show)
{
	HMODULE dll;
	EntryPoint entry;
	char *p, *func = 0, *args = 0, error[1024];

	for (p = cmdline; *p; ++p)
		if (*p == ',')
		{
			*p++ = 0;
			func = p;
			break;
		}
	for (; *p; ++p)
		if (*p == ' ')
		{
			*p++ = 0;
			args = p;
			break;
		}

	if (func)
	{
		if ((dll = LoadLibrary(cmdline)))
		{
			if ((entry = (EntryPoint)GetProcAddress(dll, func)))
				entry(0, dll, args, show);
			else
			{
				wsprintf(error, "Entry point %s not found in %s", cmdline, func);
				MessageBox(0, error, "Error", MB_ICONHAND | MB_OK);
			}
			FreeLibrary(dll);
		}
		else
		{
			wsprintf(error, "Failed to load %s", cmdline);
			MessageBox(0, error, "Error", MB_ICONHAND | MB_OK);
		}
	}

	return 0;
}

/* vim: set ts=4 sw=4 noet: */
